==> eiffelstudio-18.11.10.2592.tar: F_code/C32/if1562.c <==
/*
 * Code for class IF_AS
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "if1562.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {IF_AS}.initialize */
void F2368_29205 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3, EIF_REFERENCE arg4, EIF_REFERENCE arg5, EIF_REFERENCE arg6, EIF_REFERENCE arg7, EIF_REFERENCE arg8)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(9);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLR(3,arg3);
	RTLR(4,arg4);
	RTLR(5,arg5);
	RTLR(6,arg6);
	RTLR(7,arg7);
	RTLR(8,arg8);
	RTLIU(9);
	
	RTEAA("initialize", 2367, Current, 0, 8, 35144);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg2;
	RTHOOK(3);
	RTAR(Current, arg3);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) arg3;
	RTHOOK(4);
	RTAR(Current, arg4);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) arg4;
	RTHOOK(5);
	RTAR(Current, arg5);
	*(EIF_REFERENCE *)(Current + _REFACS_5_) = (EIF_REFERENCE) arg5;
	RTHOOK(6);
	if ((EIF_BOOLEAN)(arg6 != NULL)) {
		RTHOOK(7);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg6) + O22390[Dtype(arg6)-2337]);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_6_0_0_0_) = (EIF_INTEGER_32) ti4_1;
	}
	RTHOOK(8);
	if ((EIF_BOOLEAN)(arg7 != NULL)) {
		RTHOOK(9);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg7) + O22390[Dtype(arg7)-2337]);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_6_0_0_1_) = (EIF_INTEGER_32) ti4_1;
	}
	RTHOOK(10);
	if ((EIF_BOOLEAN)(arg8 != NULL)) {
		RTHOOK(11);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg8) + O22390[Dtype(arg8)-2337]);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_6_0_0_2_) = (EIF_INTEGER_32) ti4_1;
	}
	RTHOOK(20);
	RTLE;
	RTEE;
}

/* {IF_AS}.process */
void F2368_29206 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("process", 2367, Current, 0, 1, 35145);
	RTHOOK(1);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R4571[Dtype(arg1)-304])(RTCW(arg1), Current);
	RTHOOK(2);
	RTEE;
}

/* {IF_AS}.if_keyword */
EIF_REFERENCE F2368_29210 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 ti4_1;
	
	
	RTEAA("if_keyword", 2367, Current, 0, 1, 35149);
	RTHOOK(1);
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_6_0_0_0_);
	RTHOOK(2);
	RTEE;
	return (EIF_REFERENCE) F2264_28008(Current, arg1, ti4_1);
}

/* {IF_AS}.condition */
EIF_REFERENCE F2368_29214 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {IF_AS}.compound */
EIF_REFERENCE F2368_29215 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {IF_AS}.elsif_list */
EIF_REFERENCE F2368_29216 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_3_);
}


/* {IF_AS}.else_part */
EIF_REFERENCE F2368_29217 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_4_);
}


/* {IF_AS}.end_keyword */
EIF_REFERENCE F2368_29218 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_5_);
}


/* {IF_AS}.first_token */
EIF_REFERENCE F2368_29219 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTEAA("first_token", 2367, Current, 0, 1, 35158);
	RTGC;
	RTHOOK(1);
	if ((EIF_BOOLEAN)(arg1 == NULL)) {
		RTHOOK(2);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		Result = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R21883[Dtype(tr1)-2264])(RTCW(tr1), arg1);
	} else {
		RTHOOK(3);
		if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_6_0_0_0_) != ((EIF_INTEGER_32) 0L))) {
			RTHOOK(4);
			RTHOOK(5);
			RTLE;
			RTEE;
			return (EIF_REFERENCE) F2368_29210(Current, arg1);
		}
	}
	RTHOOK(6);
	RTLE;
	RTEE;
	return Result;
}

/* {IF_AS}.last_token */
EIF_REFERENCE F2368_29220 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTEAA("last_token", 2367, Current, 0, 1, 35159);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_5_);
	Result = F2338_28814(RTCW(tr1), arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {IF_AS}.is_equivalent */
EIF_BOOLEAN F2368_29221 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("is_equivalent", 2367, Current, 0, 1, 35160);
	RTGC;
	RTHOOK(1);
	Result = '\0';
	tb1 = '\0';
	tb2 = '\0';
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_2_);
	if (F2264_27990(Current, *(EIF_REFERENCE *)(Current + _REFACS_2_), tr1)) {
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		tb2 = F2264_27990(Current, *(EIF_REFERENCE *)(Current + _REFACS_1_), tr1);
	}
	if (tb2) {
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_4_);
		tb1 = F2264_27990(Current, *(EIF_REFERENCE *)(Current + _REFACS_4_), tr1);
	}
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_3_);
		Result = F2264_27990(Current, *(EIF_REFERENCE *)(Current + _REFACS_3_), tr1);
	}
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit1562 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C32/if1562.c <==
/*
 * Code for class IF_AS
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "if1562.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {IF_AS}.initialize */
void F2372_29215 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3, EIF_REFERENCE arg4, EIF_REFERENCE arg5, EIF_REFERENCE arg6, EIF_REFERENCE arg7, EIF_REFERENCE arg8)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(9);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLR(3,arg3);
	RTLR(4,arg4);
	RTLR(5,arg5);
	RTLR(6,arg6);
	RTLR(7,arg7);
	RTLR(8,arg8);
	RTLIU(9);
	
	RTEAA("initialize", 2371, Current, 0, 8, 35173);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg2;
	RTHOOK(3);
	RTAR(Current, arg3);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) arg3;
	RTHOOK(4);
	RTAR(Current, arg4);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) arg4;
	RTHOOK(5);
	RTAR(Current, arg5);
	*(EIF_REFERENCE *)(Current + _REFACS_5_) = (EIF_REFERENCE) arg5;
	RTHOOK(6);
	if ((EIF_BOOLEAN)(arg6 != NULL)) {
		RTHOOK(7);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg6) + O22428[Dtype(arg6)-2344]);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_6_0_0_0_) = (EIF_INTEGER_32) ti4_1;
	}
	RTHOOK(8);
	if ((EIF_BOOLEAN)(arg7 != NULL)) {
		RTHOOK(9);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg7) + O22428[Dtype(arg7)-2344]);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_6_0_0_1_) = (EIF_INTEGER_32) ti4_1;
	}
	RTHOOK(10);
	if ((EIF_BOOLEAN)(arg8 != NULL)) {
		RTHOOK(11);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg8) + O22428[Dtype(arg8)-2344]);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_6_0_0_2_) = (EIF_INTEGER_32) ti4_1;
	}
	RTHOOK(20);
	RTLE;
	RTEE;
}

/* {IF_AS}.process */
void F2372_29216 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("process", 2371, Current, 0, 1, 35174);
	RTHOOK(1);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R4591[Dtype(RTCW(arg1))-309])(arg1, Current);
	RTHOOK(2);
	RTEE;
}

/* {IF_AS}.if_keyword */
EIF_REFERENCE F2372_29220 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("if_keyword", 2371, Current, 0, 1, 35178);
	RTHOOK(1);
	RTHOOK(2);
	RTEE;
	return (EIF_REFERENCE) F2271_28056(Current, arg1, *(EIF_INTEGER_32 *)(Current+ _LNGOFF_6_0_0_0_));
}

/* {IF_AS}.first_token */
EIF_REFERENCE F2372_29229 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTEAA("first_token", 2371, Current, 0, 1, 35187);
	RTGC;
	RTHOOK(1);
	if ((EIF_BOOLEAN)(arg1 == NULL)) {
		RTHOOK(2);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		Result = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R21921[Dtype(RTCW(tr1))-2271])(tr1, arg1);
	} else {
		RTHOOK(3);
		if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_6_0_0_0_) != ((EIF_INTEGER_32) 0L))) {
			RTHOOK(4);
			Result = F2372_29220(Current, arg1);
			RTHOOK(5);
			RTLE;
			RTEE;
			return (EIF_REFERENCE) Result;
		}
	}
	RTHOOK(6);
	RTLE;
	RTEE;
	return Result;
}

/* {IF_AS}.last_token */
EIF_REFERENCE F2372_29230 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTEAA("last_token", 2371, Current, 0, 1, 35188);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_5_);
	Result = F2345_28862(RTCW(tr1), arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {IF_AS}.is_equivalent */
EIF_BOOLEAN F2372_29231 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("is_equivalent", 2371, Current, 0, 1, 35189);
	RTGC;
	RTHOOK(1);
	Result = '\0';
	tb1 = '\0';
	tb2 = '\0';
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_2_);
	if (F2271_28038(Current, *(EIF_REFERENCE *)(Current + _REFACS_2_), tr1)) {
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		tb2 = F2271_28038(Current, *(EIF_REFERENCE *)(Current + _REFACS_1_), tr1);
	}
	if (tb2) {
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_4_);
		tb1 = F2271_28038(Current, *(EIF_REFERENCE *)(Current + _REFACS_4_), tr1);
	}
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_3_);
		Result = F2271_28038(Current, *(EIF_REFERENCE *)(Current + _REFACS_3_), tr1);
	}
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit1562 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
